==> py5paisa-0.7.12.tar.gz: py5paisa-0.7.12/py5paisa/urlconst.py <==

BaseUrl = 'https://Openapi.5paisa.com/VendorsAPI/Service1.svc/'


LOGIN_ROUTE = f'{BaseUrl}V4/LoginRequestMobileNewbyEmail'

SCRIP_MASTER_ROUTE=f'{BaseUrl}ScripMaster/segment/All'

MARGIN_ROUTE = f'{BaseUrl}V4/Margin'
ORDER_BOOK_ROUTE = f'{BaseUrl}V3/OrderBook'
HOLDINGS_ROUTE = f'{BaseUrl}V3/Holding'
POSITIONS_ROUTE = f'{BaseUrl}V2/NetPositionNetWise'

ORDER_PLACEMENT_ROUTE = f'{BaseUrl}V1/PlaceOrderRequest'
ORDER_MODIFY_ROUTE = f'{BaseUrl}V1/ModifyOrderRequest'
ORDER_CANCEL_ROUTE = f'{BaseUrl}V1/CancelOrderRequest'
ORDER_STATUS_ROUTE = f'{BaseUrl}V2/OrderStatus'
TRADE_INFO_ROUTE = f'{BaseUrl}TradeInformation'

BRACKET_MOD_ROUTE = f'{BaseUrl}ModifyBracketOrderRequest'
BRACKET_ORDER_ROUTE = f'{BaseUrl}BracketOrderRequest'
BRACKET_CANCEL_ROUTE = f'{BaseUrl}CancelBracketOrderRequest'

COVER_MOD_ROUTE = f'{BaseUrl}ModifyCoverOrderequest'
COVER_ORDER_ROUTE = f'{BaseUrl}CoverOrderRequest'
COVER_CANCEL_ROUTE = f'{BaseUrl}CancelCoverOrderRequest'

MARKET_FEED_ROUTE = f'{BaseUrl}MarketFeed'
MARKET_FEED_ROUTE_BY_SCRIP = f'{BaseUrl}V1/MarketFeed'
LOGIN_CHECK_ROUTE = "https://openfeed.5paisa.com/Feeds/api/UserActivity/LoginCheck"

MARKET_DEPTH_ROUTE = f'{BaseUrl}/MarketDepth'
MARKET_DEPTH_BY_SYMBOL_ROUTE = f'{BaseUrl}V1/MarketDepth'
MARKET_DEPTH_BY_SCRIP = f'{BaseUrl}V2/MarketDepth'
JWT_VALIDATION_ROUTE = "https://Openapi.indiainfoline.com/VendorsAPI/Service1.svc/JWTOpenApiValidation"
#HISTORICAL_DATA_ROUTE = "https://openapi.5paisa.com/historical/" old url
HISTORICAL_DATA_ROUTE = "https://openapi.5paisa.com/V2/historical/"
IDEAS_ROUTE = f'{BaseUrl}TraderIDEAs'

TRADEBOOK_ROUTE = f'{BaseUrl}V1/TradeBook'
GET_REQUEST_TOKEN_ROUTE = f'{BaseUrl}TOTPLogin'
ACCESS_TOKEN_ROUTE = f'{BaseUrl}GetAccessToken'
MARKET_STATUS_ROUTE = f'{BaseUrl}MarketStatus'
TRADE_HISTORY_ROUTE = f'{BaseUrl}TradeHistory'

GET_BASKET_ROUTE = f'{BaseUrl}GetBaskets'
CREATE_BASKET_ROUTE = f'{BaseUrl}CreateBasket'
RENAME_BASKET_ROUTE = f'{BaseUrl}EditBasketName'
DELETE_BASKET_ROUTE = f'{BaseUrl}DeleteBasket'
CLONE_BASKET_ROUTE = f'{BaseUrl}CloneBasket'
EXECUTE_BASKET_ROUTE = f'{BaseUrl}ExecuteBasket'
GET_ORDER_IN_BASKET_ROUTE = f'{BaseUrl}GetOrderInBasket'
ADD_BASKET_ORDER_ROUTE = f'{BaseUrl}AddOrderToBasket'
OPTION_CHAIN_ROUTE = f'{BaseUrl}V2/GetExpiryForSymbolOptions'
GET_OPTION_CHAIN_ROUTE = f'{BaseUrl}GetOptionsForSymbol'
CANCEL_BULK_ORDER_ROUTE = f'{BaseUrl}CancelOrderBulk'
SQUAREOFF_ROUTE = f'{BaseUrl}SquareOffAll'
POSITION_CONVERSION_ROUTE = f'{BaseUrl}PositionConversion'
MARKET_DEPTH_ROUTE_20 = "https://openapi.5paisa.com/marketfeed-token/token"
APIUID = 'ka7SFqAU6SC'
ORDERMARGIN_ROUTE='https://Swarajtrade.5paisa.com/5P_PreOrderMargin/Service1.svc/V1/PreOrdMarginCalculationVendor'
ADDVTTORDER_ROUTE=f'{BaseUrl}AddVTTOrder'
CALVTTORDER_ROUTE=f'{BaseUrl}CancelVTTOrder'
MODVTTORDER_ROUTE=f'{BaseUrl}ModifyVTTOrder'
GETVTTORDER_ROUTE=f'{BaseUrl}GetVTTOrder'
HISVTTORDER_ROUTE=f'{BaseUrl}GetHistoryVTTOrder'
BASKETMARGIN_ROUTE= f'{BaseUrl}PreOrdMarginCalculationBulkVendor'
PLACEORDERBULK_ROUTE= f'{BaseUrl}PlaceOrderBulk'

==> py5paisa-0.7.13.tar.gz: py5paisa-0.7.13/py5paisa/urlconst.py <==

BaseUrl = 'https://Openapi.5paisa.com/VendorsAPI/Service1.svc/'


LOGIN_ROUTE = f'{BaseUrl}V4/LoginRequestMobileNewbyEmail'

SCRIP_MASTER_ROUTE=f'{BaseUrl}ScripMaster/segment/All'

MARGIN_ROUTE = f'{BaseUrl}V4/Margin'
ORDER_BOOK_ROUTE = f'{BaseUrl}V3/OrderBook'
HOLDINGS_ROUTE = f'{BaseUrl}V3/Holding'
POSITIONS_ROUTE = f'{BaseUrl}V2/NetPositionNetWise'

ORDER_PLACEMENT_ROUTE = f'{BaseUrl}V1/PlaceOrderRequest'
ORDER_MODIFY_ROUTE = f'{BaseUrl}V1/ModifyOrderRequest'
ORDER_CANCEL_ROUTE = f'{BaseUrl}V1/CancelOrderRequest'
ORDER_STATUS_ROUTE = f'{BaseUrl}V2/OrderStatus'
TRADE_INFO_ROUTE = f'{BaseUrl}TradeInformation'

BRACKET_MOD_ROUTE = f'{BaseUrl}ModifyBracketOrderRequest'
BRACKET_ORDER_ROUTE = f'{BaseUrl}BracketOrderRequest'
BRACKET_CANCEL_ROUTE = f'{BaseUrl}CancelBracketOrderRequest'

COVER_MOD_ROUTE = f'{BaseUrl}ModifyCoverOrderequest'
COVER_ORDER_ROUTE = f'{BaseUrl}CoverOrderRequest'
COVER_CANCEL_ROUTE = f'{BaseUrl}CancelCoverOrderRequest'

MARKET_FEED_ROUTE = f'{BaseUrl}MarketFeed'
MARKET_FEED_ROUTE_BY_SCRIP = f'{BaseUrl}V1/MarketFeed'
LOGIN_CHECK_ROUTE = "https://openfeed.5paisa.com/Feeds/api/UserActivity/LoginCheck"

MARKET_DEPTH_ROUTE = f'{BaseUrl}/MarketDepth'
MARKET_DEPTH_BY_SYMBOL_ROUTE = f'{BaseUrl}V1/MarketDepth'
MARKET_DEPTH_BY_SCRIP = f'{BaseUrl}V2/MarketDepth'
JWT_VALIDATION_ROUTE = "https://Openapi.indiainfoline.com/VendorsAPI/Service1.svc/JWTOpenApiValidation"
#HISTORICAL_DATA_ROUTE = "https://openapi.5paisa.com/historical/" old url
HISTORICAL_DATA_ROUTE = "https://openapi.5paisa.com/V2/historical/"
IDEAS_ROUTE = f'{BaseUrl}TraderIDEAs'

TRADEBOOK_ROUTE = f'{BaseUrl}V1/TradeBook'
GET_REQUEST_TOKEN_ROUTE = f'{BaseUrl}TOTPLogin'
ACCESS_TOKEN_ROUTE = f'{BaseUrl}GetAccessToken'
MARKET_STATUS_ROUTE = f'{BaseUrl}MarketStatus'
TRADE_HISTORY_ROUTE = f'{BaseUrl}TradeHistory'

GET_BASKET_ROUTE = f'{BaseUrl}GetBaskets'
CREATE_BASKET_ROUTE = f'{BaseUrl}CreateBasket'
RENAME_BASKET_ROUTE = f'{BaseUrl}EditBasketName'
DELETE_BASKET_ROUTE = f'{BaseUrl}DeleteBasket'
CLONE_BASKET_ROUTE = f'{BaseUrl}CloneBasket'
EXECUTE_BASKET_ROUTE = f'{BaseUrl}ExecuteBasket'
GET_ORDER_IN_BASKET_ROUTE = f'{BaseUrl}GetOrderInBasket'
ADD_BASKET_ORDER_ROUTE = f'{BaseUrl}AddOrderToBasket'
OPTION_CHAIN_ROUTE = f'{BaseUrl}V2/GetExpiryForSymbolOptions'
GET_OPTION_CHAIN_ROUTE = f'{BaseUrl}GetOptionsForSymbol'
CANCEL_BULK_ORDER_ROUTE = f'{BaseUrl}CancelOrderBulk'
SQUAREOFF_ROUTE = f'{BaseUrl}SquareOffAll'
POSITION_CONVERSION_ROUTE = f'{BaseUrl}PositionConversion'
MARKET_DEPTH_ROUTE_20 = "https://openapi.5paisa.com/marketfeed-token/token"
APIUID = 'ka7SFqAU6SC'
ORDERMARGIN_ROUTE=f'{BaseUrl}V1/PreOrdMarginCalculationVendor'
ADDVTTORDER_ROUTE=f'{BaseUrl}AddVTTOrder'
CALVTTORDER_ROUTE=f'{BaseUrl}CancelVTTOrder'
MODVTTORDER_ROUTE=f'{BaseUrl}ModifyVTTOrder'
GETVTTORDER_ROUTE=f'{BaseUrl}GetVTTOrder'
HISVTTORDER_ROUTE=f'{BaseUrl}GetHistoryVTTOrder'
BASKETMARGIN_ROUTE= f'{BaseUrl}PreOrdMarginCalculationBulkVendor'
PLACEORDERBULK_ROUTE= f'{BaseUrl}PlaceOrderBulk'
NETPOSITION_ROUTE= f'{BaseUrl}V4/NetPosition'
MARKETSNAPSHOT_ROUTE = f'{BaseUrl}MarketSnapshot'
